@@ -1,7 +1,7 @@
 import json
 import requests
 
-def error_handler(resource):
+def error_handler(response):
     print(f"Status: {response.status_code}")
     print(f"ErrorMessage: {response.json()['error']}")
     return {response.json()['error']}
